@@ -586,8 +586,8 @@ class Page(Plugin):
 
         #if the destination is somewhere special, change the language
         if dest == 'CN':
-            self.preseed('debian-installer/locale', 'zh_CN')
-            self.ui.controller.translate('zh_CN')
+            self.preseed('debian-installer/locale', 'zh_CN.UTF-8')
+            self.ui.controller.translate('zh_CN.UTF-8')
 
     def explode_utility_partition(self):
         '''Explodes all content onto the utility partition
@@ -1018,21 +1018,13 @@ class Page(Plugin):
             self.ui.set_advanced(twaddle, twiddle[twaddle])
         self.ui.set_type(rec_type)
 
-        #set the language in the UI
+        #Make sure some locale was set so we can guarantee automatic mode
         try:
-            language = self.db.get('debian-installer/language')
+            language = self.db.get('debian-installer/locale')
         except debconf.DebconfError:
             language = ''
         if not language:
-            with open('/proc/cmdline', 'r') as rfd:
-                for item in rfd.readline().split():
-                    if 'locale=' in item:
-                        items = item.split('=')
-                        if len(items) > 1:
-                            language = items[1]
-                            break
-        if language:
-            self.preseed('debian-installer/locale', language)
+            self.preseed('debian-installer/locale', 'en')
             self.ui.controller.translate(language)
 
         #Clarify which device we're operating on initially in the UI
@@ -1345,19 +1337,17 @@ manually to proceed.")
                         raise RuntimeError, ("Error creating new %s mb grub partition on %s" % (grub_size, self.device))
 
             up_part = '2'
-            command = ('parted', '-a', 'optimal', '-s', self.device, 'mkpartfs', 'primary', 'fat16', str(grub_size), str(grub_size+up_size))
-            result = misc.execute_root(*command)
-            if result is False:
-                raise RuntimeError, ("Error creating new %s mb utility partition on %s" % (up_size, self.device))
+            commands = [('parted', '-a', 'optimal', '-s', self.device, 'mkpartfs', 'primary', 'fat16', str(grub_size), str(grub_size+up_size)),
+                        ('parted', '-s', self.device, 'set', up_part, 'diag', 'on'),
+                        ('parted', '-s', self.device, 'name', up_part, 'DellUtility')]
+            for command in commands:
+                result = misc.execute_root(*command)
+                if result is False:
+                    raise RuntimeError, ("Error creating new %s mb utility partition on %s" % (up_size, self.device))
 
-            #TODO: clean method to write a dell bootsector while GPT.
-            #with misc.raised_privileges():
-            #    #parted marks it as w95 fat16 (LBA).  It *needs* to be type 'de'
-            #    data = 't\nde\n\nw\n'
-            #    magic.fetch_output(['fdisk', self.device], data)
-            #
-            #    #build the bootsector of the partition
-            #    magic.write_up_bootsector(self.device, up_part)
+            with misc.raised_privileges():
+                #build the bootsector of the partition
+                magic.write_up_bootsector(self.device, up_part)
 
 
             #GPT Doesn't support active partitions, so we must install directly to the disk rather than
